[Bedework-commit] webapps r734 - releases/bedework-3.4.1.1/webcommon/src/org/bedework/webcommon/event

svnadmin at bedework.org svnadmin at bedework.org
Tue Apr 22 09:46:04 EDT 2008


Author: douglm
Date: 2008-04-22 09:46:03 -0400 (Tue, 22 Apr 2008)
New Revision: 734

Modified:
   releases/bedework-3.4.1.1/webcommon/src/org/bedework/webcommon/event/UpdateEventAction.java
Log:
Dump all multi-valued properties on trace

Rearrange the update slightly for publish

Modified: releases/bedework-3.4.1.1/webcommon/src/org/bedework/webcommon/event/UpdateEventAction.java
===================================================================
--- releases/bedework-3.4.1.1/webcommon/src/org/bedework/webcommon/event/UpdateEventAction.java	2008-04-21 03:55:45 UTC (rev 733)
+++ releases/bedework-3.4.1.1/webcommon/src/org/bedework/webcommon/event/UpdateEventAction.java	2008-04-22 13:46:03 UTC (rev 734)
@@ -299,16 +299,6 @@
       return res;
     }
 
-    /* ------------------- web submit comment ---------------------------- */
-
-    if (submitApp) {
-      String x = request.getReqPar("xbwsubmitcomment");
-      if (x != null) {
-        ev.addXproperty(new BwXproperty(BwXproperty.bedeworkSubmitComment,
-                                        null, x));
-      }
-    }
-
     /* -------------------------- Dates ------------------------------ */
 
     res = form.getEventDates().updateEvent(ev);
@@ -397,11 +387,10 @@
 
     ev.setPublick(publicAdmin);
 
     /* ------------------ web submit - change owner -------------------------- */
 
     if (publishEvent) {
-      /* Change owner and copy entities */
-      changeOwner(ev, svci);
+      copyEntities(ev, svci);
     }
 
     /* ------------------ final validation -------------------------- */
@@ -410,6 +399,13 @@
       return forwardValidationError;
     }
 
+    /* ------------------ web submit - change owner -------------------------- */
+
+    if (publishEvent) {
+      /* Change owner and copy entities */
+      changeOwner(ev, svci);
+    }
+
     try {
       if (adding) {
         svci.getEventsHandler().add(destCal, ei, true);
@@ -491,11 +487,14 @@
 
   private void changeOwner(BwEvent ev,
                            CalSvcI svci) throws CalFacadeException {
-    BwUser origOwner = ev.getOwner();
-
     svci.getEventsHandler().claim(ev);
     ev.setCreator(svci.getUser());
+  }
 
+  private void copyEntities(BwEvent ev,
+                            CalSvcI svci) throws CalFacadeException {
+    BwUser origOwner = ev.getOwner();
+
     /* Copy event entities */
     BwLocation loc = ev.getLocation();
     if ((loc != null) && !loc.getPublick()) {
@@ -397,11 +387,10 @@
     ev.setPublick(publicAdmin);
 
-    /* ------------------ web submit - change owner -------------------------- */
+    /* ------------------ web submit - copy entities ------------------------ */
 
     if (publishEvent) {



More information about the Bedework-commit mailing list